(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     74582,       1465]
NotebookOptionsPosition[     73664,       1431]
NotebookOutlinePosition[     74021,       1447]
CellTagsIndexPosition[     73978,       1444]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["numerov with  linear potential", "Text",
 CellChangeTimes->{{3.530623600094739*^9, 3.5306236061891823`*^9}, {
  3.53062819660878*^9, 3.530628199510346*^9}, {3.545474815222856*^9, 
  3.545474816660483*^9}, {3.545476693782196*^9, 3.545476694684114*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Potential", ",", " ", 
    RowBox[{"desired", " ", "max", " ", "energy"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", "s_", "]"}], ":=", 
     RowBox[{"Abs", "[", "s", "]"}]}], ";", 
    RowBox[{
     SubscriptBox["\[Epsilon]", "m"], "=", "20."}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"determine", " ", "grid"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rturn", "=", 
     RowBox[{
      RowBox[{"FindRoot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"V", "[", "s", "]"}], "\[Equal]", 
         SubscriptBox["\[Epsilon]", "m"]}], ",", 
        RowBox[{"{", 
         RowBox[{"s", ",", 
          SubscriptBox["\[Epsilon]", "m"]}], "}"}]}], "]"}], 
      "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], ";", 
    RowBox[{"d", "=", 
     FractionBox["1", 
      SqrtBox[
       RowBox[{"2", 
        SubscriptBox["\[Epsilon]", "m"]}]]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"n", "=", 
     RowBox[{"Round", "[", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["rturn", "d"], "+", 
         RowBox[{"4", "\[Pi]"}]}], " ", ")"}]}], "]"}]}], ";", 
    RowBox[{"s", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"d", " ", 
           RowBox[{"(", 
            RowBox[{"n", "+", "1"}], ")"}]}], 
          RowBox[{"2", " "}]]}], "+", 
        RowBox[{"d", " ", "i"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "n"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"calculate", " ", "KE", " ", "matrix"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[DoubleStruckCapitalI]", "[", 
      RowBox[{"n_", ",", "d_"}], "]"}], ":=", 
     RowBox[{"DiagonalMatrix", "[", 
      RowBox[{
       RowBox[{"1", "+", 
        RowBox[{"0", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", 
           RowBox[{"Abs", "[", "d", "]"}]}], "]"}]}]}], ",", "d"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"B", "=", 
     RowBox[{
      FractionBox["1.", "12"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[DoubleStruckCapitalI]", "[", 
         RowBox[{"n", ",", 
          RowBox[{"-", "1"}]}], "]"}], "+", 
        RowBox[{"10", " ", 
         RowBox[{"\[DoubleStruckCapitalI]", "[", 
          RowBox[{"n", ",", "0"}], "]"}]}], "+", 
        RowBox[{"\[DoubleStruckCapitalI]", "[", 
         RowBox[{"n", ",", "1"}], "]"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"A", "=", 
     RowBox[{
      FractionBox["1", 
       RowBox[{" ", 
        SuperscriptBox["d", "2"]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[DoubleStruckCapitalI]", "[", 
         RowBox[{"n", ",", 
          RowBox[{"-", "1"}]}], "]"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"\[DoubleStruckCapitalI]", "[", 
          RowBox[{"n", ",", "0"}], "]"}]}], "+", 
        RowBox[{"\[DoubleStruckCapitalI]", "[", 
         RowBox[{"n", ",", "1"}], "]"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"KE", "=", 
     RowBox[{
      FractionBox[
       RowBox[{"-", "1"}], "2"], 
      RowBox[{
       RowBox[{"Inverse", "[", "B", "]"}], ".", "A"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", "Hamiltonian", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"H", "=", 
     RowBox[{"KE", "+", 
      RowBox[{"DiagonalMatrix", "[", 
       RowBox[{"V", "[", "s", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{"(*", 
    RowBox[{"Energies", ",", " ", "wavefunctions"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eval", ",", "evec"}], "}"}], "=", 
     RowBox[{"Eigensystem", "[", "H", "]"}]}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.5454807045136013`*^9, 3.5454810263476553`*^9}, {
   3.545481070714772*^9, 3.545481248481571*^9}, {3.545481280377705*^9, 
   3.545481444074996*^9}, {3.545481532328985*^9, 3.545481564351429*^9}, {
   3.545481594997755*^9, 3.545481596464952*^9}, {3.545481638480659*^9, 
   3.545481649462401*^9}, 3.545481698379489*^9, {3.545481748217443*^9, 
   3.545481771600506*^9}, {3.545481881237506*^9, 3.545481884263851*^9}, {
   3.5454821083724937`*^9, 3.545482113626301*^9}, 3.545482318114657*^9, {
   3.54548237055591*^9, 3.545482396617209*^9}, {3.54548267675106*^9, 
   3.54548267815862*^9}, {3.545490339034691*^9, 3.545490361958728*^9}, {
   3.545505955030525*^9, 3.545505985532735*^9}}],

Cell["Theoretical Eigenvalues", "Text",
 CellChangeTimes->{{3.545485499854081*^9, 3.545485505213456*^9}, 
   3.545515007485747*^9, 3.545515466790464*^9, {3.54551636463615*^9, 
   3.545516365112433*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rootsa", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["2", 
         RowBox[{
          RowBox[{"-", "1"}], "/", "3"}]]}], "*", 
       RowBox[{"AiryAiZero", "[", "n", "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "65"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AiryAiPrimeZeros", "=", 
   RowBox[{"DeleteDuplicates", "[", 
    RowBox[{
     RowBox[{"Sort", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["2", 
            RowBox[{
             RowBox[{"-", "1"}], "/", "3"}]]}], "*", "x"}], "/.", 
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{"AiryAiPrime", "[", "x", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", 
             RowBox[{
              RowBox[{"-", "n"}], "+", 
              FractionBox["n", "2"]}]}], "}"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "2", ",", "100"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"#1", "\[Equal]", "#2"}], " ", "&"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zeros", "=", 
   RowBox[{"Sort", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Append", "[", 
      RowBox[{"rootsa", ",", "AiryAiPrimeZeros"}], "]"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zeross", "=", 
   RowBox[{"Delete", "[", 
    RowBox[{"zeros", ",", "1"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.543184707251732*^9, 3.543184747272908*^9}, {
  3.543189151636365*^9, 3.543189164417669*^9}, {3.543189493531399*^9, 
  3.543189509665508*^9}, {3.543189651131457*^9, 3.543189651291788*^9}, {
  3.543230000659326*^9, 3.543230005471826*^9}, {3.543230112503076*^9, 
  3.5432301292687016`*^9}, {3.545486584025956*^9, 3.545486589854081*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "cvmit"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Failed to converge to the requested accuracy or precision \
within \[NoBreak]\\!\\(100\\)\[NoBreak] iterations. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/cvmit\\\", ButtonNote -> \
\\\"FindRoot::cvmit\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.54575778934877*^9, 3.5491930343088083`*^9, 
  3.549215636503652*^9}]
}, Open  ]],

Cell["Theoretical Eigenfunctions", "Text",
 CellChangeTimes->{{3.545516372094926*^9, 3.545516376237107*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
  "Normalization", " ", "Constants", " ", "for", " ", "first", " ", "65", " ",
    "eigenfunctions"}], "*)"}]], "Input",
 CellChangeTimes->{{3.545516378632839*^9, 3.545516389133895*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"AAA", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["2", 
         RowBox[{"2", "/", "3"}]], "*", 
        RowBox[{"Integrate", "[", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"AiryAi", "[", "x", "]"}], "2"], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["2", 
               RowBox[{"(", 
                RowBox[{"1", "/", "3"}], ")"}]]}], "*", 
             RowBox[{"zeross", "[", 
              RowBox[{"[", "n", "]"}], "]"}]}], ",", "\[Infinity]"}], "}"}]}],
          "]"}]}], ")"}], 
      RowBox[{"-", "0.5"}]], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "65"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.543185085709306*^9, 3.54318512426532*^9}, {
   3.543189656657578*^9, 3.543189662079867*^9}, 3.5432301227374516`*^9, {
   3.545483727854081*^9, 3.545483774229081*^9}, {3.545483853463456*^9, 
   3.545483863135331*^9}, {3.545483940385331*^9, 3.545483948088456*^9}, {
   3.545485847213456*^9, 3.545485849385331*^9}, {3.545485937010331*^9, 
   3.545485946275956*^9}, {3.545486476697831*^9, 3.545486488557206*^9}, {
   3.545486593057206*^9, 3.545486617072831*^9}, 3.545486669525956*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"psiith", "[", 
   RowBox[{"n_", ",", "s_"}], "]"}], ":=", 
  RowBox[{"Piecewise", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"AAA", "[", 
         RowBox[{"[", "n", "]"}], "]"}], "*", 
        RowBox[{"AiryAi", "[", 
         RowBox[{
          SuperscriptBox["2", 
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}]], "*", 
          RowBox[{"(", 
           RowBox[{"s", "-", 
            RowBox[{"zeross", "[", 
             RowBox[{"[", "n", "]"}], "]"}]}], ")"}]}], "]"}]}], ",", 
       RowBox[{"s", ">", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], 
         RowBox[{"n", "+", "1"}]], "*", 
        RowBox[{"AAA", "[", 
         RowBox[{"[", "n", "]"}], "]"}], "*", 
        RowBox[{"AiryAi", "[", 
         RowBox[{
          SuperscriptBox["2", 
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}]], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "s"}], "-", 
            RowBox[{"zeross", "[", 
             RowBox[{"[", "n", "]"}], "]"}]}], ")"}]}], "]"}]}], ",", 
       RowBox[{"s", "<", "0"}]}], "}"}]}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.545515122993319*^9, 3.545515197955985*^9}, {
  3.545515340567121*^9, 3.54551534761689*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"theory", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"psiith", "[", 
      RowBox[{"50", ",", "s"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", 
       RowBox[{"-", "22"}], ",", "22"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"f", "[", "i_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"d", " ", 
       RowBox[{"(", 
        RowBox[{"n", "+", "1"}], ")"}]}], ")"}]}], "/", "2"}], " ", "+", 
   RowBox[{"d", " ", "i"}]}]}], "\n", 
 RowBox[{
  RowBox[{"scale", "=", 
   RowBox[{"Map", "[", 
    RowBox[{"f", ",", 
     RowBox[{"Range", "[", 
      RowBox[{"Length", "[", 
       RowBox[{"evec", "[", 
        RowBox[{"[", 
         RowBox[{"-", "50"}], "]"}], "]"}], "]"}], "]"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"result", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"scale", ",", 
      RowBox[{
       RowBox[{"evec", "[", 
        RowBox[{"[", 
         RowBox[{"-", "50"}], "]"}], "]"}], "/", 
       SqrtBox["d"]}]}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"numerov", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"result", ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\n"}], "Input",
 CellChangeTimes->{{3.545515200622239*^9, 3.545515250917299*^9}, {
  3.545516344925292*^9, 3.545516356559825*^9}, {3.545757814943931*^9, 
  3.5457578218228197`*^9}, {3.545757862628937*^9, 3.54575786294049*^9}, {
  3.5457579005872707`*^9, 3.5457579022188177`*^9}, {3.545757939299382*^9, 
  3.5457579425053053`*^9}, {3.545758182398693*^9, 3.5457581900483418`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p1", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"numerov", ",", "theory", ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"FontSize", "\[Rule]", "16"}], ")"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25"}], ",", "25"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4"}], ",", "0.4"}], "}"}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.545516213656164*^9, 3.545516216846009*^9}, {
  3.549194009600543*^9, 3.5491940389569693`*^9}, {3.549215953827149*^9, 
  3.549215969567843*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJw1mHlczekXx4u0KdJCiEpFaN8QOc9ozFiSpWm00CT7Mmo0NaJ0Q4rByFCK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     "]]}, {{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUWXc41t8bFjKy9957v1aJOGggI6OkkhGhEiUUSVJUIkJWZVX23vs8eN/X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       "]], LineBox[CompressedData["
1:eJwUWnc4lu8XN8rIyN5771mh6D6JzJDIqIiKkm9UKpXSRDIyKiGiqMjI3jfv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       
       "]]}, {}}, {{}, {}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  ImageSize->500,
  LabelStyle->(FontSize -> 16),
  PlotRange->{{-25, 25}, {-0.4, 0.4}},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{3.549215970316518*^9, 3.549216068604589*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"res", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"evec", "[", 
      RowBox[{"[", 
       RowBox[{"-", "50"}], "]"}], "]"}], "/", 
     SqrtBox["d"]}], "-", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"psiith", "[", 
       RowBox[{"50", ",", 
        RowBox[{
        "scale", "\[LeftDoubleBracket]", "m", "\[RightDoubleBracket]"}]}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"Length", "[", "scale", "]"}]}], "}"}]}], "]"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5491930696802797`*^9, 3.549193135315892*^9}, {
   3.54919317911244*^9, 3.549193220701974*^9}, {3.549193318363254*^9, 
   3.549193364408276*^9}, 3.5492159819032707`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"resplot", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"scale", ",", "res"}], "}"}], "\[Transpose]"}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "0.2"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"FontSize", "\[Rule]", "16"}], ")"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "25"}], ",", "25"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.01"}], ",", "0.01"}], "}"}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.549193376869656*^9, 3.549193396197276*^9}, {
   3.5491935895199127`*^9, 3.54919362605259*^9}, {3.5491940257978907`*^9, 
   3.5491940295974607`*^9}, 3.54919406655618*^9, {3.5491949152061443`*^9, 
   3.549194919635104*^9}, {3.549195052840901*^9, 3.5491950609495897`*^9}, {
   3.549215708754691*^9, 3.549215713016608*^9}, {3.549215760785412*^9, 
   3.549215776478592*^9}, {3.549215850028818*^9, 3.549215917041226*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJw1mHdYVEcXxgdRsIAixa4sHQHpoB+Wc6Kxgy4WRFBcQcSKFClS5Bo1EGPB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    "]]},
  AspectRatio->0.2,
  Axes->True,
  ImageSize->500,
  LabelStyle->(FontSize -> 16),
  PlotRange->{{-25, 25}, {-0.01, 0.01}},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{{3.549215859349844*^9, 3.549215918268915*^9}, 
   3.5492160241099367`*^9, 3.549216072261345*^9}]
}, Open  ]]
},
WindowSize->{985, 1154},
WindowMargins->{{Automatic, 246}, {Automatic, 0}},
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (November 6, \
2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 257, 3, 26, "Text"],
Cell[817, 25, 4721, 136, 351, "Input"],
Cell[5541, 163, 202, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[5768, 170, 1975, 56, 97, "Input"],
Cell[7746, 228, 545, 11, 23, "Message"]
}, Open  ]],
Cell[8306, 242, 108, 1, 26, "Text"],
Cell[8417, 245, 227, 5, 27, "Input"],
Cell[8647, 252, 1349, 33, 34, "Input"],
Cell[9999, 287, 1424, 43, 48, "Input"],
Cell[11426, 332, 1649, 50, 115, "Input"],
Cell[CellGroupData[{
Cell[13100, 386, 726, 20, 27, "Input"],
Cell[13829, 408, 52836, 873, 340, "Output"]
}, Open  ]],
Cell[66680, 1284, 730, 22, 38, "Input"],
Cell[CellGroupData[{
Cell[67435, 1310, 1131, 27, 43, "Input"],
Cell[68569, 1339, 5079, 89, 132, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
