(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     11432,        284]
NotebookOptionsPosition[     11025,        265]
NotebookOutlinePosition[     11383,        281]
CellTagsIndexPosition[     11340,        278]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["numerov with  linear potential", "Text",
 CellChangeTimes->{{3.530623600094739*^9, 3.5306236061891823`*^9}, {
  3.53062819660878*^9, 3.530628199510346*^9}, {3.545474815222856*^9, 
  3.545474816660483*^9}, {3.545476693782196*^9, 3.545476694684114*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Potential", ",", " ", 
    RowBox[{"desired", " ", "max", " ", "energy"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", "s_", "]"}], ":=", 
     RowBox[{"Abs", "[", "s", "]"}]}], ";", 
    RowBox[{"\[Epsilon]m", "=", "20."}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"determine", " ", "grid"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"st", "=", 
     RowBox[{
      RowBox[{"FindRoot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"V", "[", "s", "]"}], "\[Equal]", "\[Epsilon]m"}], ",", 
        RowBox[{"{", 
         RowBox[{"s", ",", "\[Epsilon]m"}], "}"}]}], "]"}], 
      "\[LeftDoubleBracket]", 
      RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ds", "=", 
     RowBox[{"1", "/", 
      SqrtBox[
       RowBox[{"2", "\[Epsilon]m"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"n", "=", 
     RowBox[{"Round", "[", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"st", "/", "ds"}], "+", 
         RowBox[{"4", "\[Pi]"}]}], " ", ")"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"s", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", "ds"}], " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"n", "+", "1"}], ")"}], "/", "2"}]}], "+", 
        RowBox[{"ds", " ", "i"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "n"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"calculate", " ", "KE", " ", "matrix"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"one", "[", 
      RowBox[{"n_", ",", "d_"}], "]"}], ":=", "\[IndentingNewLine]", 
     RowBox[{"DiagonalMatrix", "[", 
      RowBox[{
       RowBox[{"1", "+", 
        RowBox[{"0", 
         RowBox[{"Range", "[", 
          RowBox[{"n", "-", 
           RowBox[{"Abs", "[", "d", "]"}]}], "]"}]}]}], ",", "d"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"B", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"one", "[", 
         RowBox[{"n", ",", 
          RowBox[{"-", "1"}]}], "]"}], "+", 
        RowBox[{"10", " ", 
         RowBox[{"one", "[", 
          RowBox[{"n", ",", "0"}], "]"}]}], "+", 
        RowBox[{"one", "[", 
         RowBox[{"n", ",", "1"}], "]"}]}], ")"}], "/", "12."}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"A", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"one", "[", 
         RowBox[{"n", ",", 
          RowBox[{"-", "1"}]}], "]"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"one", "[", 
          RowBox[{"n", ",", "0"}], "]"}]}], "+", 
        RowBox[{"one", "[", 
         RowBox[{"n", ",", "1"}], "]"}]}], ")"}], "/", 
      SuperscriptBox["ds", "2"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"KE", "=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"Inverse", "[", "B", "]"}], ".", "A"}]}], "/", "2"}]}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{"(*", "Hamiltonian", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"H", "=", 
     RowBox[{"KE", "+", 
      RowBox[{"DiagonalMatrix", "[", 
       RowBox[{"V", "[", "s", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{"(*", 
    RowBox[{"Energies", ",", " ", "wavefunctions"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eval", ",", "evec"}], "}"}], "=", 
     RowBox[{"Eigensystem", "[", "H", "]"}]}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.5454807045136013`*^9, 3.5454810263476553`*^9}, {
   3.545481070714772*^9, 3.545481248481571*^9}, {3.545481280377705*^9, 
   3.545481444074996*^9}, {3.545481532328985*^9, 3.545481564351429*^9}, {
   3.545481594997755*^9, 3.545481596464952*^9}, {3.545481638480659*^9, 
   3.545481649462401*^9}, 3.545481698379489*^9, {3.545481748217443*^9, 
   3.545481771600506*^9}, {3.545481881237506*^9, 3.545481884263851*^9}, {
   3.5454821083724937`*^9, 3.545482113626301*^9}, 3.545482318114657*^9, {
   3.54548237055591*^9, 3.545482396617209*^9}, {3.54548267675106*^9, 
   3.54548267815862*^9}, {3.545490339034691*^9, 3.545490361958728*^9}, {
   3.549274144402577*^9, 3.549274291029804*^9}, {3.5492743319815817`*^9, 
   3.549274354243351*^9}, {3.549274387407687*^9, 3.549274424600335*^9}, {
   3.54927585623384*^9, 3.549275878063847*^9}},
 FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"s", ",", 
      RowBox[{"evec", "\[LeftDoubleBracket]", 
       RowBox[{"-", "20"}], "\[RightDoubleBracket]"}]}], "}"}], 
    "\[Transpose]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.549274460187056*^9, 3.549274497080138*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJw1mHk4lOsbx0eKkmWyZStLi8k6ZmzJzPNE29EQTrKVopK0iSTnKFvKr5U2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    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{{3.5492744798011827`*^9, 3.549274498865981*^9}, 
   3.549276054312447*^9}]
}, Open  ]]
},
WindowSize->{949, 773},
WindowMargins->{{Automatic, 301}, {168, Automatic}},
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (November 6, \
2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 257, 3, 26, "Text"],
Cell[817, 25, 4624, 132, 357, "Input"],
Cell[CellGroupData[{
Cell[5466, 161, 372, 10, 27, "Input"],
Cell[5841, 173, 5168, 89, 238, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
